@@ -1,12 +1,12 @@
 """
 Core Hyperpython API
 """
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 __author__ = 'Fábio Macêdo Mendes'
 
 # Ugly hack to make it possible to store __version__ directly on __init__.py
 try:
-    from .core import Element, Text, Block
+    from .core import Element, Text, Block, Json, Component
     from .html import html, render
     from .tags import (
         HTML5, h,
